# Pygendata

`pygendata` is a python library for generating test data from files (csv, tsv, ddl, json) or extending the libraries built in `template` system
to generate data

# Installation
To install pygendata you can use your favorite python package installer
```
pip install pygendata
```

Once you install the package you will want to modify your `.bash_profile` ,`.zshrc` or `.bashrc` file and set an alias to pygendata

```
alias pygendata="<Path/to/install/location>"
```

To test if the installation worked correctly you can use the python repl and try importing the package
```
python

import pygendata
```

# More Coming Soon...